@@ -1,4 +1,6 @@
+import requests
 import unittest
+from unittest.mock import MagicMock, patch
 
 import mock
 import pytest
@@ -29,11 +31,27 @@ class TestDataStore(unittest.TestCase):
     def test_create_data_store(self):
         DataStore(self.data_store_inputs)
 
-    def test_schemas_access(self):
+    @patch('treeschema.api.client.r.get')  
+    def test_schemas_access(self, mock_get):
+        test_obj = {'meta': {'next_page': None}, 'data_schemas': []}
+        response = requests.Response()
+        response.status_code = 200
+        response.json = MagicMock()
+        response.json.return_value = test_obj
+        mock_get.return_value = response
+
         ds = DataStore(self.data_store_inputs)
         ds._schemas_by_id is ds.schemas
 
-    def test_add_remove_schemas(self):
+    @patch('treeschema.api.client.r.get')  
+    def test_add_remove_schemas(self, mock_get):
+        test_obj = {'meta': {'next_page': None}, 'data_schemas': []}
+        response = requests.Response()
+        response.status_code = 200
+        response.json = MagicMock()
+        response.json.return_value = test_obj
+        mock_get.return_value = response
+
         ds = DataStore(self.data_store_inputs)
         
         m = mock.Mock()
